<img align="right" width="300" height="300" src="https://github.com/piScope/PetraM_Base/blob/job_submission_adjustment/resources/app_logo.png">

## PetraM_Base (Base Package for Petra-M)

Petra-M (Physics Equation Translator for MFEM) is a physics layer built
on the top of PyMFEM, a python wrapper for Modular FEM library
(MFEM: http://mfem.org). 

Petra-M Base includes
 - Physics modeling interface on piScope.
 - Weakform module to define PDE using MFEM integrators.
 - Distance module to define PDE for measuring distance

Additinal Petra-M submodules are available from different repository.
 - PetraM_RF : 3D frequency domain Maxwell equation
 - PetraM_MUMPS : interface to MUMPS direct linear solver
 - PetraM_Geom : Geometry editor module using GMSH/OpenCascade

## Publications
  S. Shiraiwa, et al. EPJ Web of Conferences 157, 03048 (2017)

### Licence
PetraM project is released under the GPL v3 license.
See files COPYRIGHT and LICENSE file for full details.

